//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "repere.h"

//---------------------------------------------------------------------------
#pragma package(smart_init)

repere::repere ()
{};
//---------------------------------------------------------------------------
repere::repere (TForm* f,double xmin,double xmax,double ymin,double ymax)
{ 	interval_x=interval(xmin,xmax);
    interval_y=interval(ymin,ymax);
	form=f;
};
//---------------------------------------------------------------------------
void repere::Clean()
{  form->Canvas->Brush->Color=clWhite;
   form->Canvas->Pen->Color=clWhite;
   form->Canvas->Rectangle (0,0,form->ClientWidth,form->ClientHeight);
}
//---------------------------------------------------------------------------
void repere::DrawBox (box& P,TColor couleurin,TColor couleurout,TBrushStyle pinceau)
{  if (P.isEmpty) return;
   form->Canvas->Brush->Style=pinceau;
   form->Canvas->Brush->Color=couleurin;
   form->Canvas->Pen->Color=couleurout;
   float ax=form->ClientWidth/(Width(interval_x));
   float bx=-ax*Inf(interval_x);
   float ay=form->ClientHeight/(-Width(interval_y));
   float by=-ay*Sup(interval_y);
   form->Canvas->Rectangle (ax*Inf(P[1])+bx,ay*Inf(P[2])+by,
                            ax*Sup(P[1])+bx+1,ay*Sup(P[2])+by-1);
}
//---------------------------------------------------------------------------
void repere::DrawCadre (box& P,TColor couleur,TPenStyle crayon,int epais=1)
{  if (P.isEmpty) return;
   DrawLine(Inf(P[1]),Inf(P[2]),Inf(P[1]),Sup(P[2]),couleur,crayon,epais);
   DrawLine(Inf(P[1]),Inf(P[2]),Sup(P[1]),Inf(P[2]),couleur,crayon,epais);
   DrawLine(Sup(P[1]),Sup(P[2]),Inf(P[1]),Sup(P[2]),couleur,crayon,epais);
   DrawLine(Sup(P[1]),Sup(P[2]),Sup(P[1]),Inf(P[2]),couleur,crayon,epais);
}
//---------------------------------------------------------------------------
void repere::DrawCadre (box& P,TColor couleur,TPenStyle crayon)
{  DrawCadre (P,couleur,crayon,1);
}
//---------------------------------------------------------------------------
void repere::DrawPoint (double x,double y,TColor couleur,int epais)
{  form->Canvas->Pen->Color=couleur;
   float ax=form->ClientWidth/(Width(interval_x));
   float bx=-ax*Inf(interval_x);
   float ay=form->ClientHeight/(-Width(interval_y));
   float by=-ay*Sup(interval_y);
   form->Canvas->Ellipse(ax*x+bx-epais,ay*y+by-epais,ax*x+bx+epais,ay*y+by+epais);
}
//---------------------------------------------------------------------------
void repere::DrawLine (double x1,double y1,double x2, double y2,TColor couleur,
                       TPenStyle crayon,int taille)
{  form->Canvas->Pen->Color=couleur;
   form->Canvas->Pen->Style=crayon;
   form->Canvas->Pen->Width=taille;
   float ax=form->ClientWidth/(Width(interval_x));
   float bx=-ax*Inf(interval_x);
   float ay=form->ClientHeight/(-Width(interval_y));
   float by=-ay*Sup(interval_y);
   form->Canvas->MoveTo (ax*x1+bx,ay*y1+by);
   form->Canvas->LineTo (ax*x2+bx,ay*y2+by);
   form->Canvas->Pen->Width=1;
}
//---------------------------------------------------------------------------
void repere::DrawPolygon(double* xa,double* ya,int imin,int imax, TColor c)
{   POINT points[100];
    float ax=form->ClientWidth/(Width(interval_x));
    float bx=-ax*Inf(interval_x);
    float ay=form->ClientHeight/(-Width(interval_y));
    float by=-ay*Sup(interval_y);
    for (int i=0; i<=imax-imin;i++)
    {   double x1=xa[i+imin];
        double y1=ya[i+imin];
        points[i] = Point(ax*x1+bx,ay*y1+by);
    }
    form->Canvas->Brush->Color = c;
    form->Canvas->Pen->Color = clBlack;
    form->Canvas->Polygon(points,13);
}
//---------------------------------------------------------------------------
void repere::DrawGrid (TColor couleur)
{  if (Width(interval_x)>1)
    { int a=INT(Inf(interval_x));
      while (a<Sup(interval_x))
        {DrawLine(a,Inf(interval_y),a,Sup(interval_y),couleur,psDash,1);
        a++; }
    }
   else
    { float a=INT(Inf(interval_x))-1;
      while (a<Sup(interval_x))
        {   DrawLine(a,Inf(interval_y),a,Sup(interval_y),couleur,psDot,1);
            a=a+0.1;
        };
    } ;
  if (Width(interval_y)>1)
    { int a=INT(Inf(interval_y));
      while (a<Sup(interval_y))
        {DrawLine(Inf(interval_x),a,Sup(interval_x),a,couleur,psDashDot,1);
        a++; }
    }
   else
    { float a=INT(Inf(interval_y))-1;
      while (a<Sup(interval_y))
        {   DrawLine(Inf(interval_x),a,Sup(interval_x),a,couleur,psDot,1);
            a=a+0.1;
        };
    }  ;
}
//---------------------------------------------------------------------------
void repere::DrawBox (box& P,TColor couleurin,TColor couleurout,TBrushStyle pinceau,int i1,int i2)
{ if (P.isEmpty) return;
  box Q(2,true);  Q[1]=P[i1];  Q[2]=P[i2];
  DrawBox (Q,couleurin,couleurout,pinceau);
}
//---------------------------------------------------------------------------
void repere::DrawData (box& Y,box& t,TColor couleur,double epais)
{ if (Y.isEmpty) return;
  box Q(2,true);
  for (int j=1;j<=Y.dim;j++)
  {  Q[1]=t[j];  Q[2]=Y[j];
     Q=Inflate(Q,epais);
     DrawBox (Q,couleur,couleur,bsSolid);
  }
  DrawLine(Inf(interval_x),0,Sup(interval_x),0,clBlack,psSolid,1);
  DrawLine(0,Inf(interval_y),0,Sup(interval_y),clBlack,psSolid,1);
}
//---------------------------------------------------------------------------
void repere::DrawCadre (box& P,TColor couleur,TPenStyle crayon,int i1,int i2)
{
  box Q(2,true);
  Q[1]=P[i1]; Q[2]=P[i2];  DrawCadre (Q,couleur,crayon,1);
}
//---------------------------------------------------------------------------



